http_headers = (
    "Content-Type",
    "x-requested-with",
    "x-csrf-token",
    "x-auth-token",
    "Authorization",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
    "X-CSRF-TOKEN",
    "X-Auth-Token",
    "X-Requested-With",
    "Accept",
    "Origin",
    "X-Requested-With",
    "Content-Type",
    "Accept",
    "X-Auth-Token",
)
